==> simplelink_lowpower_f3_sdk_9_14_01_16__win.zip: simplelink_lowpower_f3_sdk_9_14_01_16/docs/rcl/html/navtreedata.js <==
var NAVTREE =
[
  [ "Radio Control Layer (RCL)", "index.html", [
    [ "RCL Architecture", "rcl_architecture.html", "rcl_architecture" ],
    [ "RCL API Overview", "rcl_api_overview.html", null ],
    [ "Glossary", "rcl_glossary.html", [
      [ "Access Address", "rcl_glossary.html#access-address", null ],
      [ "Accept list", "rcl_glossary.html#ble-acceptlist", null ],
      [ "Advertising Channel", "rcl_glossary.html#advertising-channel", null ],
      [ "Advertising Physical Channel PDU", "rcl_glossary.html#advertising-pdu", null ],
      [ "Advertising Interval", "rcl_glossary.html#advertising-interval", null ],
      [ "Auxiliary Advertising Segment", "rcl_glossary.html#auxiliary-advertising-segment", null ],
      [ "Aux Pointer", "rcl_glossary.html#aux-pointer", null ],
      [ "Aux Offset Field of Aux Pointer", "rcl_glossary.html#aux-pointer-aux-offset", null ],
      [ "Aux Phy Field of Aux Pointer", "rcl_glossary.html#aux-pointer-aux-phy", null ],
      [ "Bluetooth Address", "rcl_glossary.html#ble-address", null ],
      [ "Bluetooth Header", "rcl_glossary.html#ble-header", null ],
      [ "Central Device", "rcl_glossary.html#central-device", null ],
      [ "Channel Map", "rcl_glossary.html#channel-map", null ],
      [ "Channel Index Field of Aux Pointer", "rcl_glossary.html#aux-pointer-ch-index", null ],
      [ "Clock Accuracy Field of Aux Pointer", "rcl_glossary.html#aux-pointer-ca", null ],
      [ "Command handler", "rcl_glossary.html#command-handler", null ],
      [ "Connection Event", "rcl_glossary.html#connection-event", null ],
      [ "Connection Interval", "rcl_glossary.html#connection-interval", null ],
      [ "Common Extended Advertising Payload Format", "rcl_glossary.html#common-extended-advertising-payload-format", null ],
      [ "Data channel", "rcl_glossary.html#data-channel", null ],
      [ "Extended advertising", "rcl_glossary.html#extended-advertising", null ],
      [ "Extended header", "rcl_glossary.html#extended-header", null ],
      [ "Extended header flags", "rcl_glossary.html#extended-header-flags", null ],
      [ "Frequency Hopping", "rcl_glossary.html#frequency-hopping", null ],
      [ "Legacy advertising", "rcl_glossary.html#legacy-advertising", null ],
      [ "Link Layer (LL)", "rcl_glossary.html#link-layer", null ],
      [ "LRF", "rcl_glossary.html#lrf", null ],
      [ "LRF event", "rcl_glossary.html#lrf-event", null ],
      [ "LRF image", "rcl_glossary.html#lrf-image", null ],
      [ "Offset Units Field of Aux Pointer", "rcl_glossary.html#aux-pointer-offset-units", null ],
      [ "Packet Format", "rcl_glossary.html#packet-format", null ],
      [ "PDU", "rcl_glossary.html#pdu", null ],
      [ "Peripheral Device", "rcl_glossary.html#peripheral-device", null ],
      [ "PHY Config", "rcl_glossary.html#phy-config", null ],
      [ "Physical Layer", "rcl_glossary.html#phy-layer", null ],
      [ "PHY switching", "rcl_glossary.html#phy-switching", null ],
      [ "Preamble", "rcl_glossary.html#preamble", null ],
      [ "Primary Advertising Channel", "rcl_glossary.html#primary-advertising-channel", null ],
      [ "PSDU", "rcl_glossary.html#psdu", null ],
      [ "Random Device Address", "rcl_glossary.html#random-device-address", null ],
      [ "RCL event", "rcl_glossary.html#rcl-event", null ],
      [ "Secondary Advertising Channel", "rcl_glossary.html#secondary-advertising-channel", null ],
      [ "Sync Info", "rcl_glossary.html#sync-info", null ],
      [ "Sync Packet Window Offset", "rcl_glossary.html#sync-packet-window-offset", null ],
      [ "Systimer", "rcl_glossary.html#systimer", null ],
      [ "Channel Sounding", "rcl_glossary.html#channel-sounding", null ],
      [ "Periodic Advertising Response Timing Information", "rcl_glossary.html#response-timing-info", null ],
      [ "ACAD", "rcl_glossary.html#acad", null ],
      [ "AD Structure", "rcl_glossary.html#ad-structure", null ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_l_r_f_8c.html",
"_l_r_f_c_c23_x0_8c.html#ae25821a5f6cd512c4f702380ce1c164d",
"_l_r_f_c_c23_x0_8h.html#ad2881f8e569ca053c5d8c771c65dfa3c",
"_r_c_l___command_8h.html#ac01715edff7456d8d1ad5810ff8d571ba7bc34fe49866562f3dd8029f34c8d11c",
"auxiliary_advertiser_handler.html",
"ble5_8c.html#af98760a0d46aeb07173014ef0e9700c7",
"commands_2ble5_8h.html#a3adfa2f0431630bad53624887870a342",
"commands_2ble5_8h.html#struct_r_c_l___c_t_x___g_e_n_e_r_i_c___t_x__t",
"commands_2ble__cs_8h.html#aaa482663773272718b8934be15d6f9c2ac07243a537318a58e4fd1324f0a27782",
"commands_2generic_8h.html#a8129e918b6457c5ebdaeaa9f61e64b46",
"dir_a097f9c534288f11bc95c57bd92be661.html",
"group__timing_handler_functions.html#ga7acb281685fc2938f11ab99ee78c4d59",
"handlers_2generic_8h.html#a22ea0ca428435fda119bf71108214078"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> simplelink_lowpower_f3_sdk_9_14_02_16__win.zip: simplelink_lowpower_f3_sdk_9_14_02_16/docs/rcl/html/navtreedata.js <==
var NAVTREE =
[
  [ "Radio Control Layer (RCL)", "index.html", [
    [ "RCL Architecture", "rcl_architecture.html", "rcl_architecture" ],
    [ "RCL API Overview", "rcl_api_overview.html", null ],
    [ "Glossary", "rcl_glossary.html", [
      [ "Access Address", "rcl_glossary.html#access-address", null ],
      [ "Accept list", "rcl_glossary.html#ble-acceptlist", null ],
      [ "Advertising Channel", "rcl_glossary.html#advertising-channel", null ],
      [ "Advertising Physical Channel PDU", "rcl_glossary.html#advertising-pdu", null ],
      [ "Advertising Interval", "rcl_glossary.html#advertising-interval", null ],
      [ "Auxiliary Advertising Segment", "rcl_glossary.html#auxiliary-advertising-segment", null ],
      [ "Aux Pointer", "rcl_glossary.html#aux-pointer", null ],
      [ "Aux Offset Field of Aux Pointer", "rcl_glossary.html#aux-pointer-aux-offset", null ],
      [ "Aux Phy Field of Aux Pointer", "rcl_glossary.html#aux-pointer-aux-phy", null ],
      [ "Bluetooth Address", "rcl_glossary.html#ble-address", null ],
      [ "Bluetooth Header", "rcl_glossary.html#ble-header", null ],
      [ "Central Device", "rcl_glossary.html#central-device", null ],
      [ "Channel Map", "rcl_glossary.html#channel-map", null ],
      [ "Channel Index Field of Aux Pointer", "rcl_glossary.html#aux-pointer-ch-index", null ],
      [ "Clock Accuracy Field of Aux Pointer", "rcl_glossary.html#aux-pointer-ca", null ],
      [ "Command handler", "rcl_glossary.html#command-handler", null ],
      [ "Connection Event", "rcl_glossary.html#connection-event", null ],
      [ "Connection Interval", "rcl_glossary.html#connection-interval", null ],
      [ "Common Extended Advertising Payload Format", "rcl_glossary.html#common-extended-advertising-payload-format", null ],
      [ "Data channel", "rcl_glossary.html#data-channel", null ],
      [ "Extended advertising", "rcl_glossary.html#extended-advertising", null ],
      [ "Extended header", "rcl_glossary.html#extended-header", null ],
      [ "Extended header flags", "rcl_glossary.html#extended-header-flags", null ],
      [ "Frequency Hopping", "rcl_glossary.html#frequency-hopping", null ],
      [ "Legacy advertising", "rcl_glossary.html#legacy-advertising", null ],
      [ "Link Layer (LL)", "rcl_glossary.html#link-layer", null ],
      [ "LRF", "rcl_glossary.html#lrf", null ],
      [ "LRF event", "rcl_glossary.html#lrf-event", null ],
      [ "LRF image", "rcl_glossary.html#lrf-image", null ],
      [ "Offset Units Field of Aux Pointer", "rcl_glossary.html#aux-pointer-offset-units", null ],
      [ "Packet Format", "rcl_glossary.html#packet-format", null ],
      [ "PDU", "rcl_glossary.html#pdu", null ],
      [ "Peripheral Device", "rcl_glossary.html#peripheral-device", null ],
      [ "PHY Config", "rcl_glossary.html#phy-config", null ],
      [ "Physical Layer", "rcl_glossary.html#phy-layer", null ],
      [ "PHY switching", "rcl_glossary.html#phy-switching", null ],
      [ "Preamble", "rcl_glossary.html#preamble", null ],
      [ "Primary Advertising Channel", "rcl_glossary.html#primary-advertising-channel", null ],
      [ "PSDU", "rcl_glossary.html#psdu", null ],
      [ "Random Device Address", "rcl_glossary.html#random-device-address", null ],
      [ "RCL event", "rcl_glossary.html#rcl-event", null ],
      [ "Secondary Advertising Channel", "rcl_glossary.html#secondary-advertising-channel", null ],
      [ "Sync Info", "rcl_glossary.html#sync-info", null ],
      [ "Sync Packet Window Offset", "rcl_glossary.html#sync-packet-window-offset", null ],
      [ "Systimer", "rcl_glossary.html#systimer", null ],
      [ "Channel Sounding", "rcl_glossary.html#channel-sounding", null ],
      [ "Periodic Advertising Response Timing Information", "rcl_glossary.html#response-timing-info", null ],
      [ "ACAD", "rcl_glossary.html#acad", null ],
      [ "AD Structure", "rcl_glossary.html#ad-structure", null ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_l_r_f_8c.html",
"_l_r_f_c_c23_x0_8c.html#ae25821a5f6cd512c4f702380ce1c164d",
"_l_r_f_c_c23_x0_8h.html#ad2881f8e569ca053c5d8c771c65dfa3c",
"_r_c_l___command_8h.html#ac01715edff7456d8d1ad5810ff8d571ba7bc34fe49866562f3dd8029f34c8d11c",
"auxiliary_advertiser_handler.html",
"ble5_8c.html#af8cdbab31631c167f06db388dd39e3ec",
"commands_2ble5_8h.html#a4029b47fe18abd5d50be147763229b2d",
"commands_2ble5_8h.html#struct_r_c_l___f_l___e_n_t_r_y__t_8____unnamed_____8ctl",
"commands_2ble__cs_8h.html#aacc247eb43e540fbd6c45afbb9b2a2eca5808b314c1ac517b4a343d99f477fe7d",
"commands_2generic_8h.html#a89f0bdaa5a7c2c80279450693ff9e2fc",
"files.html",
"group__timing_handler_functions.html#gab77782ad69707cc082dc7bb5f8305142",
"handlers_2generic_8h.html#afaaed90be14e326b73149c7b2552ab3a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
